Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
JwtPayloadFields []string `json:"JwtPayloadFields,omitempty"`
Alg string `json:"Alg,omitempty"`
Secret []string `json:"Secret,omitempty"`
Sources []Source `json:"Sources,omitempty"`
InjectNewHeaders map[string]HeaderValue `json:"InjectNewHeaders,omitempty"`
ExpirationMessage string `json:"ExpirationMessage,omitempty"`
ErrorMessage string `json:"ErrorMessage,omitempty"`
RoutesToBypassTokenExpiration []RouteMatch `json:"RoutesToBypassTokenExpiration,omitempty"`
RoutesToBypassJwtValidation []PublicRouteMatch `json:"RoutesToBypassJwtValidation,omitempty"`
}
Config holds the plugin configuration
type HeaderValue ¶
type HeaderValue struct {
From []string `json:"From,omitempty"`
Values []string `json:"Values,omitempty"`
}
HeaderValue defines header values to inject
type JwtPlugin ¶
type JwtPlugin struct {
// contains filtered or unexported fields
}
JwtPlugin implements the Traefik middleware interface
type PublicHeaderValue ¶
type PublicHeaderValue struct {
From []string `json:"From,omitempty"`
Key []string `json:"Key,omitempty"`
}
PublicHeaderValue defines header values to inject for public routes
type PublicRouteMatch ¶
type PublicRouteMatch struct {
Match string `json:"match,omitempty"`
InjectNewHeaders map[string]PublicHeaderValue `json:"InjectNewHeaders,omitempty"`
}
PublicRouteMatch contains a Traefik route matcher expression and headers to inject
type RouteMatch ¶
type RouteMatch struct {
Match string `json:"match,omitempty"`
}
RouteMatch contains a Traefik route matcher expression
Click to show internal directories.
Click to hide internal directories.